# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-06-02 13:44:17
:LastEditTime: 2021-04-16 15:48:43
:LastEditors: HuangJingCan
:description: 奖品相关
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.enum import OperationType
from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.throw_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *
from seven_cloudapp.models.db_models.prize.prize_roster_model import *
from seven_cloudapp.models.db_models.throw.throw_goods_model import *


class PrizeListHandler(SevenBaseHandler):
    """
    :description: 奖品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 奖品列表
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param ascription_type：奖品归属（0-活动奖品1-任务奖品）
        :return: PageInfo
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        ascription_type = int(self.get_param("ascription_type", 0))

        condition = "act_id=%s AND ascription_type=%s"
        order_by = "sort_index desc"
        params = [act_id, ascription_type]

        if act_id <= 0:
            return self.reponse_json_error_params()

        act_prize_model = ActPrizeModel(context=self)

        prize_all_count = 0
        prize_surplus_count = 0
        prize_lottery_count = 0
        prize_release_count = 0
        sum_probability = {'probability': 0}

        if ascription_type == 0:
            # 奖品总件数
            prize_all_count = act_prize_model.get_total(condition, params=params)
            # 库存不足奖品件数
            prize_surplus_count = act_prize_model.get_total(condition + " AND surplus=0", params=params)
            # 可被抽中奖品件数
            prize_lottery_count = act_prize_model.get_total(condition + " AND probability>0 AND surplus>0 AND is_release=1", params=params)
            # 上架奖品件数
            prize_release_count = act_prize_model.get_total(condition + " AND is_release=1", params=params)
            #奖品总权重
            sum_probability = act_prize_model.get_dict(condition + " AND is_release=1", field="sum(probability) as probability", params=params)

        page_list, total = act_prize_model.get_dict_page_list("*", page_index, page_size, condition, "", order_by, params)

        if ascription_type == 0:
            #强制命中信息
            must_prize_list = [must_prize for must_prize in page_list if must_prize["force_count"] > 0]
            prize_roster_model = PrizeRosterModel(context=self)
            prize_roster_total = prize_roster_model.get_total("act_id=%s", params=act_id)
            for must_item in must_prize_list:
                page_total = int(prize_roster_total / must_item["force_count"])
                prize_roster_after_list = prize_roster_model.get_dict_list("act_id=%s", "", "id asc", str(page_total * must_item["force_count"]) + "," + str((page_total * must_item["force_count"]) + must_item["force_count"]), params=act_id)
                area_must_count = must_item["force_count"]
                is_exist = 0
                if (len(prize_roster_after_list) > 0):
                    prize_roster_after_list.reverse()
                    for roster_after_item in prize_roster_after_list:
                        if roster_after_item["prize_id"] == must_item["id"]:
                            is_exist = 1
                            area_must_count = must_item["force_count"] - len(prize_roster_after_list)
                            sum_probability["probability"] = int(sum_probability["probability"]) - must_item["probability"]
                            break
                        else:
                            area_must_count += -1
                must_item["area_must_count"] = area_must_count
                must_item["is_area_selected"] = is_exist
            page_list = SevenHelper.merge_dict_list(page_list, "id", must_prize_list, "id", "area_must_count,is_area_selected")

        for page in page_list:
            # page["prize_detail"] = ast.literal_eval(page["prize_detail"]) if page["prize_detail"] else []
            page["prize_detail"] = self.json_loads(page["prize_detail"]) if page["prize_detail"] else []
            page["goods_code_list"] = self.json_loads(page["goods_code_list"]) if page["goods_code_list"] else []
            page["sku_detail"] = self.json_loads(page["sku_detail"]) if page["sku_detail"] else []

        page_info = PageInfo(page_index, page_size, total, page_list)

        page_info.prize_all_count = prize_all_count
        page_info.prize_surplus_count = prize_surplus_count
        page_info.prize_lottery_count = prize_lottery_count
        page_info.prize_release_count = prize_release_count
        page_info.prize_sum_probability = int(sum_probability["probability"]) if sum_probability["probability"] else 0

        return self.reponse_json_success(page_info)


class PrizeHandler(SevenBaseHandler):
    """
    :description: 奖品保存
    """
    @filter_check_params("app_id,act_id")
    def post_async(self):
        """
        :description: 奖品保存
        :param prize_id：奖品id
        :param prize_type 奖品类型（1实物2店铺商品3优惠券4参与奖）
        :return: reponse_json_success
        :last_editors: LaiKaiXiang
        """
        prize_id = int(self.get_param("prize_id", 0))
        act_id = int(self.get_param("act_id", 0))
        award_id = self.get_param("award_id")
        app_id = self.get_param("app_id")
        owner_open_id = self.get_param("owner_open_id")
        machine_id = int(self.get_param("machine_id", 0))
        ascription_type = int(self.get_param("ascription_type", 0))
        prize_name = self.get_param("prize_name")
        prize_title = self.get_param("prize_title")
        prize_pic = self.get_param("prize_pic")
        prize_detail = self.get_param("prize_detail")
        goods_id = int(self.get_param("goods_id", 0))
        goods_code = self.get_param("goods_code")
        goods_code_list = self.get_param("goods_code_list")
        coupon_type = int(self.get_param("coupon_type", 0))
        right_ename = self.get_param("right_ename")
        pool_id = self.get_param("pool_id")
        coupon_start_date = self.get_param("coupon_start_date")
        coupon_end_date = self.get_param("coupon_end_date")
        prize_type = int(self.get_param("prize_type", 0))
        prize_price = self.get_param("prize_price")
        probability = int(self.get_param("probability", 0))
        surplus = int(self.get_param("surplus", 0))
        is_surplus = int(self.get_param("is_surplus", 0))
        is_prize_notice = int(self.get_param("is_prize_notice", 1))
        prize_limit = int(self.get_param("prize_limit", 0))
        prize_total = int(self.get_param("prize_total", 0))
        lottery_type = int(self.get_param("lottery_type", 1))
        force_count = int(self.get_param("force_count", 0))
        tag_name = self.get_param("tag_name")
        tag_id = int(self.get_param("tag_id", 0))
        # hand_out = int(self.get_param("hand_out", 0))
        is_sku = int(self.get_param("is_sku", 0))
        sort_index = int(self.get_param("sort_index", 0))
        is_release = int(self.get_param("is_release", 1))
        sku_detail = self.get_param("sku_detail")
        lottery_sum = int(self.get_param("lottery_sum", 0))

        # self.logging_link_info(self.request.uri + "-PrizeHandler-保存奖品" + str(self.request_params))
        if act_id <= 0:
            return self.reponse_json_error_params()

        act_prize_model = ActPrizeModel(context=self)
        act_prize = None
        if prize_id > 0:
            act_prize = act_prize_model.get_entity_by_id(prize_id)

        if not act_prize:
            act_prize = ActPrize()

        old_act_prize = deepcopy(act_prize)

        act_prize.act_id = act_id
        act_prize.award_id = award_id
        act_prize.app_id = app_id
        act_prize.owner_open_id = owner_open_id
        act_prize.machine_id = machine_id
        act_prize.ascription_type = ascription_type
        act_prize.prize_name = prize_name
        act_prize.prize_title = prize_title
        act_prize.prize_pic = prize_pic
        act_prize.prize_detail = prize_detail if prize_detail != "" else []
        act_prize.goods_id = goods_id
        act_prize.goods_code = goods_code
        act_prize.goods_code_list = goods_code_list if goods_code_list != "" else []
        # 奖品类型为优惠券时
        if prize_type == 3:
            act_prize.coupon_type = coupon_type
            act_prize.right_ename = right_ename
            act_prize.pool_id = pool_id
            act_prize.coupon_start_date = coupon_start_date if coupon_start_date else "1900-01-01 00:00:00"
            act_prize.coupon_end_date = coupon_end_date if coupon_end_date else "2900-01-01 00:00:00"
        act_prize.prize_type = prize_type
        act_prize.prize_price = prize_price
        act_prize.probability = probability
        act_prize.is_surplus = is_surplus
        act_prize.is_prize_notice = is_prize_notice
        act_prize.prize_limit = prize_limit
        act_prize.lottery_type = lottery_type
        act_prize.force_count = force_count
        act_prize.tag_name = tag_name
        act_prize.tag_id = tag_id
        # act_prize.hand_out = hand_out
        act_prize.is_sku = is_sku
        act_prize.sort_index = sort_index
        act_prize.is_release = is_release
        act_prize.sku_detail = sku_detail if sku_detail != "" else {}
        act_prize.lottery_sum = lottery_sum
        act_prize.modify_date = self.get_now_datetime()

        # 奖品类型为参与奖时
        surplus = 9999 if prize_type == 4 else surplus
        prize_total = 9999 if prize_type == 4 else prize_total

        if prize_id > 0:
            if surplus > 0:
                act_prize.surplus = surplus
            self.create_operation_log(OperationType.update.value, "act_prize_tb", "PrizeHandler", None, act_prize)
            act_prize_model.update_entity(act_prize)
            if surplus == 0:
                operate_num = prize_total - act_prize.prize_total
                act_prize_model.update_table(f"surplus=surplus+{operate_num},prize_total=prize_total+{operate_num}", "id=%s", act_prize.id)
            # ThrowModel(context=self).throw_goods_add(prize_id, act_prize.app_id, act_prize.act_id, act_prize.goods_id, old_act_prize.act_id, old_act_prize.goods_id, self.get_now_datetime())
        else:
            act_prize.create_date = act_prize.modify_date
            act_prize.surplus = surplus if surplus > 0 else prize_total
            act_prize.prize_total = prize_total
            act_prize.id = act_prize_model.add_entity(act_prize)
            self.create_operation_log(OperationType.add.value, "act_prize_tb", "PrizeHandler", old_act_prize, act_prize)
            # ThrowModel(context=self).throw_goods_add(prize_id, act_prize.app_id, act_prize.act_id, act_prize.goods_id, 0, 0, self.get_now_datetime())

        return self.reponse_json_success(act_prize.id)


class PrizeDelHandler(SevenBaseHandler):
    """
    :description: 删除奖品
    """
    @filter_check_params("prize_id")
    def get_async(self):
        """
        :description: 删除奖品
        :param prize_id：奖品id
        :return: reponse_json_success
        :last_editors: HuangJingCan
        """
        prize_id = int(self.get_param("prize_id", 0))

        if prize_id <= 0:
            return self.reponse_json_error_params()

        ActPrizeModel(context=self).del_entity("id=%s", prize_id)

        self.create_operation_log(OperationType.delete.value, "act_prize_tb", "PrizeDelHandler", None, prize_id)

        return self.reponse_json_success()


class PrizeReleaseHandler(SevenBaseHandler):
    """
    :description: 上下架奖品
    """
    @filter_check_params("prize_id")
    def get_async(self):
        """
        :description: 上下架奖品
        :param prize_id：奖品id
        :param is_release：0-下架，1-上架
        :return: 
        :last_editors: HuangJingCan
        """
        prize_id = int(self.get_param("prize_id", 0))
        is_release = int(self.get_param("is_release", 0))
        modify_date = self.get_now_datetime()

        if prize_id <= 0:
            return self.reponse_json_error_params()

        ActPrizeModel(context=self).update_table("is_release=%s,modify_date=%s", "id=%s", [is_release, modify_date, prize_id])

        return self.reponse_json_success()


class CheckRightEnameHandler(SevenBaseHandler):
    """
    :description: 判断奖品里面有没有添加这张优惠券
    """
    @filter_check_params("right_ename")
    def get_async(self):
        """
        :description: 判断奖品里面有没有添加这张优惠券
        :param right_ename：优惠券标识
        :return reponse_json_success
        :last_editors: HuangJingCan
        """
        right_ename = self.get_param("right_ename")

        count = ActPrizeModel(context=self).get_total("right_ename=%s", params=right_ename)
        if count > 0:
            return self.reponse_json_error()

        return self.reponse_json_success()


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-06-02 11:08:39
:LastEditTime: 2021-06-02 15:14:51
:LastEditors: HuangJingCan
:description: 订单相关
"""
from seven_cloudapp.handlers.seven_base import *
from seven_cloudapp.libs.customize.oss2help import *

from seven_cloudapp.models.seven_model import *
from seven_cloudapp.models.db_models.pay.pay_order_model import *
from seven_cloudapp.models.db_models.prize.prize_order_model import *
from seven_cloudapp.models.db_models.prize.prize_roster_model import *
from seven_cloudapp.models.db_models.endbox.endbox_order_model import *
from seven_cloudapp.models.db_models.ip.ip_series_model import *


class PayOrderListHandler(SevenBaseHandler):
    """
    :description: 用户购买订单
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户购买订单
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param user_open_id：用户唯一标识
        :param nick_name：用户昵称
        :param pay_date_start：订单支付时间开始
        :param pay_date_end：订单支付时间结束
        :return: 列表
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        user_open_id = self.get_param("user_open_id")
        user_nick = self.get_param("nick_name")
        pay_date_start = self.get_param("pay_date_start")
        pay_date_end = self.get_param("pay_date_end")

        condition = "act_id=%s"
        params = [act_id]

        if user_open_id:
            condition += " AND open_id=%s"
            params.append(user_open_id)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if pay_date_start:
            condition += " AND pay_date>=%s"
            params.append(pay_date_start)
        if pay_date_end:
            condition += " AND pay_date<=%s"
            params.append(pay_date_end)

        page_list, total = PayOrderModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", "pay_date desc", params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


class PrizeOrderListHandler(SevenBaseHandler):
    """
    :description: 用户奖品订单
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户奖品订单
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param order_no：订单号
        :param nick_name：用户昵称
        :param real_name：用户名字
        :param telephone：联系电话
        :param adress：收货地址
        :param order_status：订单状态
        :param create_date_start：订单创建时间开始
        :param create_date_end：订单创建时间结束
        :return: 列表
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        order_no = self.get_param("order_no")
        user_nick = self.get_param("nick_name")
        real_name = self.get_param("real_name")
        telephone = self.get_param("telephone")
        adress = self.get_param("adress")
        order_status = int(self.get_param("order_status", -1))
        create_date_start = self.get_param("create_date_start")
        create_date_end = self.get_param("create_date_end")

        condition = "act_id=%s"
        params = [act_id]

        if order_no:
            condition += " AND order_no=%s"
            params.append(order_no)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if real_name:
            condition += " AND real_name=%s"
            params.append(real_name)
        if telephone:
            condition += " AND telephone=%s"
            params.append(telephone)
        if adress:
            adress = f"%{adress}%"
            condition += " AND adress LIKE %s"
            params.append(adress)
        if order_status >= 0:
            condition += " AND order_status=%s"
            params.append(order_status)
        if create_date_start:
            condition += " AND create_date>=%s"
            params.append(create_date_start)
        if create_date_end:
            condition += " AND create_date<=%s"
            params.append(create_date_end)

        page_list, total = PrizeOrderModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", "id desc", params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


class PrizeRosterListHandler(SevenBaseHandler):
    """
    :description: 用户奖品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户奖品列表
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param machine_id：机台id
        :param prize_order_id：奖品订单id
        :param prize_type：奖品类型（1实物2店铺商品3优惠券4参与奖5谢谢参与）
        :param nick_name：用户昵称
        :param is_submit：是否提交
        :param order_status：订单状态
        :param create_date_start：订单创建时间开始
        :param create_date_end：订单创建时间结束
        :param user_open_id：用户唯一标识
        :return: list
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        machine_id = int(self.get_param("machine_id", 0))
        prize_order_id = int(self.get_param("prize_order_id", 0))
        user_nick = self.get_param("nick_name")
        is_submit = self.get_param("is_submit")
        prize_type = int(self.get_param("prize_type", 0))
        order_status = int(self.get_param("order_status", -1))
        create_date_start = self.get_param("create_date_start")
        create_date_end = self.get_param("create_date_end")
        user_open_id = self.get_param("user_open_id")

        condition = "act_id=%s"
        params = [act_id]

        if machine_id > 0:
            condition += " AND machine_id=%s"
            params.append(machine_id)
        if prize_order_id > 0:
            condition += " AND prize_order_id=%s"
            params.append(prize_order_id)
        if prize_type > 0:
            condition += " AND prize_type=%s"
            params.append(prize_type)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if is_submit and is_submit != "-1":
            if is_submit == "0":
                condition += " AND prize_order_id=0"
            else:
                condition += " AND prize_order_id>0"
        if order_status >= 0:
            condition += " AND order_status=%s"
            params.append(order_status)
        if create_date_start:
            condition += " AND create_date>=%s"
            params.append(create_date_start)
        if create_date_end:
            condition += " AND create_date<=%s"
            params.append(create_date_end)
        if user_open_id:
            condition += " AND open_id=%s"
            params.append(user_open_id)

        page_list, total = PrizeRosterModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", "id desc", params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


class PrizeOrderStatusHandler(SevenBaseHandler):
    """
    :description: 更新用户奖品订单状态
    """
    @filter_check_params("prize_order_id,order_status")
    def post_async(self):
        """
        :description: 更新用户奖品订单状态
        :param prize_order_id：奖品订单id
        :param order_status：订单状态
        :param express_company：快递公司
        :param express_no：快递单号
        :return: reponse_json_success
        :last_editors: HuangJingCan
        """
        prize_order_id = int(self.get_param("prize_order_id", 0))
        order_status = int(self.get_param("order_status", 0))
        express_company = self.get_param("express_company")
        express_no = self.get_param("express_no")
        now_datetime = self.get_now_datetime()

        prize_order_model = PrizeOrderModel(context=self)
        prize_roster_model = PrizeRosterModel(context=self)

        if order_status == 1:
            update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s,modify_date=%s"
            params = [express_company, express_no, now_datetime, now_datetime, prize_order_id]
            prize_order_model.update_table(update_sql, "id=%s", params)
            prize_roster_model.update_table("order_status=%s", "prize_order_id=%s", [order_status, prize_order_id])

            return self.reponse_json_success({"express_company": express_company, "express_no": express_no, "deliver_date": now_datetime})
        else:
            prize_order_model.update_table("order_status=%s,modify_date=%s", "id=%s", [order_status, now_datetime, prize_order_id])
            prize_roster_model.update_table("order_status=%s", "prize_order_id=%s", [order_status, prize_order_id])

            return self.reponse_json_success()


class PrizeOrderRemarksHandler(SevenBaseHandler):
    """
    :description: 更新用户奖品订单备注
    """
    @filter_check_params("prize_order_id")
    def post_async(self):
        """
        :description: 更新用户奖品订单备注
        :param prize_order_id：奖品订单id
        :param remarks：备注
        :return: 
        :last_editors: HuangJingCan
        """
        prize_order_id = int(self.get_param("prize_order_id", 0))
        remarks = self.get_param("remarks")

        PrizeOrderModel(context=self).update_table("remarks=%s", "id=%s", [remarks, prize_order_id])

        return self.reponse_json_success()


class PrizeOrderExportHandler(SevenBaseHandler):
    """
    :description: 导出订单
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 导出订单
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param order_no：订单号
        :param order_status：订单状态
        :param nick_name：用户昵称
        :param is_machine：是否机台
        :return str
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 500))
        act_id = int(self.get_param("act_id", 0))
        order_no = self.get_param("order_no")
        order_status = int(self.get_param("order_status", -1))
        user_nick = self.get_param("nick_name")
        real_name = self.get_param("real_name")
        # 0-没关联机台或者价格挡位，1-关联机台，2-关联价格挡位
        is_machine_gear = config.get_value("is_machine_gear", 0)

        condition = "act_id=%s"
        params = [act_id]

        if order_no != "":
            params.append(order_no)
            condition += " AND order_no=%s"
        if user_nick != "":
            params.append(user_nick)
            condition += " AND user_nick=%s"
        if real_name:
            condition += " AND real_name=%s"
            params.append(real_name)
        if order_status >= 0:
            params.append(order_status)
            condition += " AND order_status=%s"

        #奖品订单
        prize_order_list_dict, total = PrizeOrderModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", "create_date desc", params)

        result_data = []
        if len(prize_order_list_dict) > 0:
            prize_order_id_list = [prize_order["id"] for prize_order in prize_order_list_dict]
            prize_order_ids = str(prize_order_id_list).strip('[').strip(']')
            #订单奖品
            prize_roster_list = PrizeRosterModel(context=self).get_dict_list("prize_order_id in (" + prize_order_ids + ")", order_by="id desc")

            for prize_order in prize_order_list_dict:
                prize_roster_list_filter = [prize_roster for prize_roster in prize_roster_list if prize_roster["prize_order_id"] == prize_order["id"]]
                for prize_roster in prize_roster_list_filter:
                    data_row = {}
                    data_row["小程序订单号"] = prize_order["order_no"]
                    data_row["淘宝子订单号"] = prize_roster["order_no"]
                    data_row["淘宝名"] = prize_order["user_nick"]
                    if is_machine_gear in (1, 2):
                        data_row["盒子名称"] = prize_roster["machine_name"]
                        data_row["盒子价格"] = str(prize_roster["machine_price"])
                    data_row["奖品名称"] = prize_roster["prize_name"]
                    data_row["商家编码"] = prize_roster["goods_code"]
                    data_row["姓名"] = prize_order["real_name"]
                    data_row["手机号"] = prize_order["telephone"]
                    data_row["省份"] = prize_order["province"]
                    data_row["城市"] = prize_order["city"]
                    data_row["区县"] = prize_order["county"]
                    data_row["街道"] = prize_order["street"]
                    data_row["收货地址"] = prize_order["adress"]
                    data_row["物流单号"] = prize_order["express_no"]
                    data_row["物流公司"] = prize_order["express_company"]
                    if str(prize_order["deliver_date"]) == "1900-01-01 00:00:00":
                        data_row["发货时间"] = ""
                    else:
                        data_row["发货时间"] = str(prize_order["deliver_date"])
                    data_row["订单状态"] = self.get_status_name(prize_order["order_status"])
                    data_row["奖品价值"] = str(prize_roster["prize_price"])
                    data_row["奖品规格"] = prize_roster["properties_name"]
                    data_row["备注"] = prize_order["remarks"]

                    result_data.append(data_row)

        resource_path = ""
        if result_data:
            # if not os.path.exists("temp"):
            #     os.makedirs("temp")
            path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
            ExcelHelper.export(result_data, path)

            resource_path = OSS2Helper().upload("", path, "test", False)

            os.remove(path)

        return self.reponse_json_success(resource_path)


class PrizeOrderImportHandler(SevenBaseHandler):
    """
    :description: 订单导入
    """
    @filter_check_params("content,act_id")
    def post_async(self):
        """
        :description: 
        :param content：base64加密后的excel内容
        :param act_id：活动id
        :return 
        :last_editors: HuangJingCan
        """
        content = self.get_param("content")
        act_id = int(self.get_param("act_id", 0))

        if act_id <= 0:
            return self.reponse_json_error("NoAct", "对不起，无效活动，无法导入订单")

        # with open('E:\Project\Tandy\gao7\web\git\TaoBaoCloud\ppmt_ykmw\content.txt', 'r') as f:
        #     content = f.read()

        # 读取内容保存到本地
        # if not os.path.exists("temp"):
        #     os.makedirs("temp")
        # data = CryptoHelper.base64_decode(content)
        data = base64.decodebytes(content.encode())
        path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
        with open(path, 'ba') as f:
            buf = bytearray(data)
            f.write(buf)
        f.close()

        order_no_index = -1
        express_no_index = -1
        express_company_index = -1

        data = ExcelHelper.input(path)
        data_total = len(data)
        # 表格头部
        if data_total > 0:
            title_list = data[0]
            if "小程序订单号" in title_list:
                order_no_index = title_list.index("小程序订单号")
            if "物流单号" in title_list:
                express_no_index = title_list.index("物流单号")
            if "物流公司" in title_list:
                express_company_index = title_list.index("物流公司")

        if order_no_index == -1 or express_no_index == -1 or express_company_index == -1:
            return self.reponse_json_error("NoTitle", "对不起,缺少必要字段，无法导入订单")

        # 数据导入
        for i in range(1, data_total):
            row = data[i]
            order_no = row[order_no_index]
            express_no = row[express_no_index]
            express_company = row[express_company_index]

            if order_no and express_no and express_company:
                update_sql = "express_no=%s, express_company=%s, order_status=1, deliver_date=%s"
                params = [express_no, express_company, self.get_now_datetime(), order_no]
                # print(order_no + express_company)
                PrizeOrderModel(context=self).update_table(update_sql, "order_no=%s", params)
                PrizeRosterModel(context=self).update_table("order_status=1", "prize_order_no=%s", [order_no])

        os.remove(path)

        # self.logging_link_info(a)
        return self.reponse_json_success()


class PrizeRosterExportHandler(SevenBaseHandler):
    """
    :description: 批量奖品列表导出
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 批量奖品列表导出
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param order_no：订单号
        :param order_status：订单状态
        :param nick_name：用户昵称
        :param is_machine：是否机台
        :return str
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 500))
        act_id = self.get_param("act_id")
        order_no = self.get_param("order_no")
        order_status = int(self.get_param("order_status", -1))
        user_nick = self.get_param("nick_name")
        prize_type = int(self.get_param("prize_type", 0))
        # 0-没关联机台或者价格挡位，1-关联机台，2-关联价格挡位
        is_machine_gear = config.get_value("is_machine_gear", 0)

        condition = "act_id=%s"
        params = [act_id]

        if order_no != "":
            params.append(order_no)
            condition += " AND order_no=%s"
        if user_nick != "":
            params.append(user_nick)
            condition += " AND user_nick=%s"
        if order_status >= 0:
            params.append(order_status)
            condition += " AND order_status=%s"
        if prize_type > 0:
            params.append(prize_type)
            condition += " AND prize_type=%s"

        #奖品订单
        prize_roster_list, total = PrizeRosterModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)

        #订单奖品
        result_data = []
        for prize_roster in prize_roster_list:
            data_row = {}
            data_row["行为编号"] = prize_roster["id"]
            data_row["淘宝子订单号"] = prize_roster["order_no"]
            data_row["淘宝名"] = prize_roster["user_nick"]
            if is_machine_gear in (1, 2):
                data_row["盒子名称"] = prize_roster["machine_name"]
                data_row["盒子价格"] = str(prize_roster["machine_price"])
            data_row["奖品名称"] = prize_roster["prize_name"]
            data_row["奖品价值"] = str(prize_roster["prize_price"])
            data_row["SKU"] = prize_roster["properties_name"]
            data_row["获得时间"] = prize_roster["create_date"]
            if prize_roster["prize_order_id"] == 0:
                data_row["状态"] = "未下单"
            else:
                data_row["状态"] = "已下单"

            result_data.append(data_row)

        resource_path = ""
        if result_data:
            path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
            ExcelHelper.export(result_data, path)

            resource_path = OSS2Helper().upload("", path, config.get_value("oss_folder"), False)

            os.remove(path)

        return self.reponse_json_success(resource_path)


class EndBoxOrderListHandler(SevenBaseHandler):
    """
    :description: 端盒订单列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 端盒订单列表
        :param act_id：活动id
        :param order_no：订单编号
        :param nick_name：淘宝名称
        :param create_date_start：开始时间
        :param create_date_end：结束时间
        :return: 
        :last_editors: HuangJianYi
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        act_id = int(self.get_param("act_id", 0))
        order_no = self.get_param("order_no")
        user_nick = self.get_param("nick_name")
        create_date_start = self.get_param("create_date_start")
        create_date_end = self.get_param("create_date_end")

        condition = "act_id=%s"
        params = [act_id]

        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if create_date_start:
            condition += " AND create_date>=%s"
            params.append(create_date_start)
        if create_date_end:
            condition += " AND create_date<=%s"
            params.append(create_date_end)

        page_list, total = EndboxOrderModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)

        if page_list:
            ip_series_dict_list = IpSeriesModel(context=self).get_dict_list(SevenHelper.get_condition_by_id_list("id", [i['series_id'] for i in page_list]))
            new_dict_list = SevenHelper.merge_dict_list(page_list, "series_id", ip_series_dict_list, "id", "series_name")
            page_info = PageInfo(page_index, page_size, total, new_dict_list)
            return self.reponse_json_success(page_info)
        else:
            return self.reponse_json_success(PageInfo(page_index, page_size, total, page_list))


# -*- coding: utf-8 -*-
"""
:Author: LaiKaiXiang
:Date: 2020-11-12 10:21:54
:LastEditTime: 2021-04-16 15:49:26
:LastEditors: HuangJingCan
:description: 任务
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.enum import OperationType
from seven_cloudapp.models.behavior_model import *
from seven_cloudapp.models.db_models.task.task_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *


class TaskSaveHandler(SevenBaseHandler):
    """
    :description 保存任务列表
    """
    # def get_async(self):
    #     task_info = TaskInfoModel(context=self).get_entity_by_id(11)
    #     self.save_orm_task_config(2, "3000000026366853", task_info.task_type, task_info.task_config, 1)
    #     task_info = TaskInfoModel(context=self).get_entity_by_id(12)
    #     self.save_orm_task_config(2, "3000000026366853", task_info.task_type, task_info.task_config, 1)

    @filter_check_params("task_list,act_id,app_id")
    def post_async(self):
        """
        :description: 保存任务列表
        :param act_id：活动id
        :param app_id：app_id
        :param task_list：任务列表
        :param is_goodslist: 商品id列表（判断是否是保存商品配置）
        :return reponse_json_success
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        app_id = self.get_param("app_id")
        is_goodslist = int(self.get_param("is_goodslist", 0))
        task_list = self.get_param("task_list")
        task_list = self.json_loads(task_list)
        task_model = TaskInfoModel(context=self)

        for item in task_list:
            if "id" in item.keys():
                task_info = task_model.get_entity_by_id(int(item["id"]))
                if task_info:
                    task_info_old = deepcopy(task_info)
                    task_info.task_type = int(item["task_type"])
                    task_info.sort_index = int(item["sort_index"])
                    task_info.is_release = int(item["is_release"])
                    task_info.modify_date = self.get_now_datetime()
                    if item.__contains__("task_config"):
                        # 浏览，收藏，指定下单任务由于数据量过多，task_config数据分次保存
                        if task_info.task_type in (6, 7, 8):
                            task_config = item["task_config"]
                            task_config_new = self.json_loads(task_info.task_config)
                            for key, value in task_config.items():
                                task_config_new[key] = value
                            task_info.task_config = self.json_dumps(task_config_new)
                        else:
                            task_info.task_config = self.json_dumps(item["task_config"])
                    is_change = int(item["is_change"]) if item.__contains__("is_change") else 0
                    if is_goodslist:
                        #保存商品配置时只更新商品配置
                        task_model.update_entity(task_info, "task_config,modify_date")
                    else:
                        task_model.update_entity(task_info, "task_config,sort_index,is_release,modify_date")

                    self.create_operation_log(OperationType.update.value, task_info.__str__(), "TaskSaveHandler", self.json_dumps(task_info_old.__dict__), self.json_dumps(task_info.__dict__))

                    self.save_orm_task_config(act_id, app_id, task_info.task_type, task_info.task_config, is_change)
            else:
                task_info = TaskInfo()
                task_info.act_id = act_id
                task_info.app_id = app_id
                task_info.task_type = int(item["task_type"])
                if item.__contains__("task_config"):
                    task_info.task_config = self.json_dumps(item["task_config"])
                task_info.sort_index = int(item["sort_index"])
                # 任务未生成时保存奖品，直接生成未发布的任务
                task_info.is_release = int(item["is_release"]) if is_goodslist == 0 else 0
                task_info.create_date = self.get_now_datetime()
                is_change = int(item["is_change"]) if item.__contains__("is_change") else 0
                task_model.add_entity(task_info)

                self.create_operation_log(OperationType.add.value, task_info.__str__(), "TaskSaveHandler", None, self.json_dumps(task_info))

                self.save_orm_task_config(act_id, app_id, task_info.task_type, task_info.task_config, is_change)

        return self.reponse_json_success()

    def save_orm_task_config(self, act_id, app_id, task_type, task_config, is_change):
        """
        :description: 增加行为映射数据
        :param act_id：活动id
        :param app_id：app_id
        :param task_type：任务类型
        :param task_config：任务配置
        :param is_change：是否变动
        :return 
        :last_editors: HuangJingCan
        """
        if task_config:
            # if type(task_config) == str:
            #     task_config = ast.literal_eval(task_config)
            task_config = self.json_loads(task_config)
            reward_list = task_config["reward_list"] if task_config.__contains__("reward_list") else []
            if reward_list:
                if is_change == 1:
                    BehaviorOrmModel(context=self).del_entity("act_id=%s and task_type=%s", [act_id, task_type])
                    if task_type == 14:
                        # 累计消费
                        for reward in reward_list:
                            self.save_orm_task(act_id, app_id, task_type, "AddUpBuy", reward['key'], f"累计满{reward['money']}元")
                    elif task_type == 15:
                        # 单笔订单消费
                        for reward in reward_list:
                            self.save_orm_task(act_id, app_id, task_type, "SingleBuy", reward['key'], f"单笔满{reward['money']}元")

    def save_orm_task(self, act_id, app_id, task_type, key_name_prefix, task_key, group_sub_name):
        """
        :description: 增加行为映射数据
        :param act_id：活动id
        :param app_id：app_id
        :param task_type：任务类型
        :param task_key：任务key
        :param group_sub_name：任务分组二级名称
        :return 
        :last_editors: HuangJingCan
        """
        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        act_type = 0
        if act_dict:
            act_type = act_dict["act_type"]
        orm_infos = []
        for i in range(3):
            behavior_orm = BehaviorOrm()
            if i == 0:
                behavior_orm.is_repeat = 1
                behavior_orm.repeat_type = 1
                behavior_orm.key_value = "参与人数"
                behavior_orm.key_name = key_name_prefix + "UserCount_" + str(task_key)
            elif i == 1:
                behavior_orm.is_repeat = 0
                behavior_orm.key_value = "完成次数"
                behavior_orm.key_name = key_name_prefix + "Count_" + str(task_key)
            else:
                behavior_orm.is_repeat = 0
                behavior_orm.key_value = "积分"
                behavior_orm.key_name = key_name_prefix + "RewardCount_" + str(task_key)
            behavior_orm.task_type = task_type
            behavior_orm.group_name = "销售数据"
            behavior_orm.group_sub_name = group_sub_name
            behavior_orm.value_type = 1
            behavior_orm.is_common = 0
            behavior_orm.sort_index = 10
            behavior_orm.app_id = app_id
            behavior_orm.act_id = act_id
            behavior_orm.act_type = act_type
            behavior_orm.create_date = self.get_now_datetime()
            orm_infos.append(behavior_orm)

        behavior_orm_model = BehaviorOrmModel(context=self)
        behavior_orm_model.add_list(orm_infos)
        behavior_orm_model.update_table("sort_index=id", "task_type=%s", task_type)


class TaskListHandler(SevenBaseHandler):
    """
    :description: 获取任务列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取任务列表
        :param act_id：活动id
        :return list
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))

        if act_id <= 0:
            return self.reponse_json_error()

        dict_task_list = TaskInfoModel(context=self).get_dict_list("act_id=%s", params=act_id)

        for item_task in dict_task_list:
            if item_task["task_config"]:
                item_task["task_config"] = self.json_loads(item_task["task_config"])
            else:
                item_task["task_config"] = {}

        return self.reponse_json_success(dict_task_list)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-24 17:26:33
:LastEditTime: 2021-04-16 10:45:17
:LastEditors: HuangJingCan
:description: App相关
"""
from seven_cloudapp.handlers.top_base import *

from seven_cloudapp.models.db_models.app.app_info_model import *
from seven_cloudapp.models.db_models.base.base_info_model import *
from seven_cloudapp.models.db_models.login.login_log_model import *


class BaseInfoHandler(SevenBaseHandler):
    """
    :description: 基础信息处理
    """
    def post_async(self):
        """
        :description: 基础信息处理入库
        :param customer_service: 客服号
        :param experience_img: 案例二维码图
        :param client_ver: 客户端版本号
        :param server_ver: 服务端版本号
        :param update_function: 版本更新内容
        :param store_study_url: 店铺装修教程图文地址（如何上架小程序）
        :param study_url: 后台配置图文教程
        :param video_url: 后台配置视频教程
        :param course_url: 主账号授权子账号教程
        :param price_gare: 价格档位说明
        :param product_price: 产品价格信息
        :param decoration_poster: 装修海报
        :param friend_link: 友情链接
        :param menu_config: 菜单配置信息
        :param is_remind_phone: 是否提醒提示配置手机号
        :return: 
        :last_editors: HuangJingCan
        """
        customer_service = self.get_param("customer_service")
        experience_img = self.get_param("experience_img")
        client_ver = self.get_param("client_ver")
        server_ver = self.get_param("server_ver")
        update_function = self.get_param("update_function")
        store_study_url = self.get_param("store_study_url")
        study_url = self.get_param("study_url")
        video_url = self.get_param("video_url")
        course_url = self.get_param("course_url")
        price_gare = self.get_param("price_gare")
        product_price = self.get_param("product_price")
        decoration_poster = self.get_param("decoration_poster")
        friend_link = self.get_param("friend_link")
        menu_config = self.get_param("menu_config")
        is_remind_phone = int(self.get_param("is_remind_phone", 0))

        # 数据入库
        base_info_model = BaseInfoModel(context=self)
        base_info = base_info_model.get_entity()

        is_add = False
        if not base_info:
            is_add = True
            base_info = BaseInfo()

        base_info.customer_service = customer_service
        base_info.experience_img = experience_img
        base_info.client_ver = client_ver
        base_info.server_ver = server_ver
        base_info.update_function = update_function
        base_info.store_study_url = store_study_url
        base_info.study_url = study_url
        base_info.video_url = video_url
        base_info.course_url = course_url
        base_info.price_gare = price_gare
        base_info.product_price = product_price
        base_info.decoration_poster = decoration_poster
        base_info.friend_link = friend_link
        base_info.menu_config = menu_config
        base_info.is_remind_phone = is_remind_phone
        base_info.modify_date = self.get_now_datetime()

        if is_add:
            base_info.create_date = base_info.modify_date
            base_info_model.add_entity(base_info)
        else:
            base_info_model.update_entity(base_info)

        return self.reponse_json_success()

    def get_async(self):
        """
        :description: 基础信息获取
        :param 
        :return: BaseInfo
        :last_editors: HuangJingCan
        """
        base_info = BaseInfoModel(context=self).get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")

        # 左上角信息
        info = {}
        info["company"] = "天志互联"
        info["miniappName"] = base_info.product_name
        info["logo"] = base_info.product_icon

        # 左边菜单
        menu_list = []
        menu = {}
        menu["name"] = "创建活动"
        menu["key"] = "create_action"
        menu_list.append(menu)
        menu = {}
        menu["name"] = "活动管理"
        menu["key"] = "act_manage"
        menu_list.append(menu)
        menu = {}
        menu["name"] = "装修教程"
        menu["key"] = "decoration_poster"
        menu_list.append(menu)
        menu = {}
        menu["name"] = "版本更新"
        menu["key"] = "update_ver"
        menu_list.append(menu)

        # 左边底部菜单
        bottom_button_list = []
        bottom_button = {}
        bottom_button["title"] = "发票管理"
        bottom_button["handling_event"] = "popup"
        bottom_button["event_name"] = "billManage"
        bottom_button_list.append(bottom_button)
        bottom_button = {}
        bottom_button["title"] = "配置教程"
        bottom_button["handling_event"] = "popup"
        bottom_button["event_name"] = "use_teaching"
        bottom_button_list.append(bottom_button)
        bottom_button = {}
        bottom_button["title"] = "联系旺旺"
        bottom_button["handling_event"] = "outtarget"
        bottom_button["event_name"] = "http://amos.alicdn.com/getcid.aw?v=2&uid=%E5%A4%A9%E5%BF%97%E4%BA%92%E8%81%94&site=cntaobao&s=1&groupid=0&charset=utf-8"
        bottom_button_list.append(bottom_button)
        bottom_button = {}
        bottom_button["title"] = "号码绑定"
        bottom_button["handling_event"] = "popup"
        bottom_button["event_name"] = "bind_phone"
        bottom_button_list.append(bottom_button)

        # 右边使用指引
        use_point_list = []
        use_point = {}
        use_point["index"] = "1"
        use_point["title"] = "创建活动并配置完成"
        use_point_list.append(use_point)
        use_point = {}
        use_point["index"] = "2"
        use_point["title"] = "将淘宝小程序装修至店铺"
        use_point_list.append(use_point)
        use_point = {}
        use_point["index"] = "3"
        use_point["title"] = "正式运营淘宝小程序"
        use_point_list.append(use_point)

        data = {}
        data["serverName"] = "在线拆盲盒模板"
        data["info"] = info
        data["menu"] = menu_list
        data["bottom_button"] = bottom_button_list
        data["use_point"] = use_point_list
        if base_info:
            # 把string转成数组对象
            base_info.update_function = self.json_loads(base_info.update_function) if base_info.update_function else []
            base_info.price_gare = self.json_loads(base_info.price_gare) if base_info.price_gare else []
            base_info.product_price = self.json_loads(base_info.product_price) if base_info.product_price else []
            base_info.decoration_poster = self.json_loads(base_info.decoration_poster) if base_info.decoration_poster else []
            base_info.friend_link = self.json_loads(base_info.friend_link) if base_info.friend_link else []
            base_info.menu_config = self.json_loads(base_info.menu_config) if base_info.menu_config else []
            data["base_info"] = base_info.__dict__

        if base_info:
            return self.reponse_json_success(data)
        else:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")


class InstantiateAppHandler(TopBaseHandler):
    """
    :description: 实例化小程序
    """
    @filter_check_params()
    def get_async(self):
        """
        :description: 实例化
        :return app_info
        :last_editors: HuangJingCan
        """
        # if self.get_is_test():
        #     return self.reponse_json_success({"app_id": "3000000026366853", "store_user_nick": "loveyouhk", "user_nick": "loveyouhk", "access_token": "50000400c44tV0dokOtB9blVhqxExuGaBgQhrVujjfJn0erSGRlxbEzI1a99a16dAZu"})
        return self.instantiate_new()


class TelephoneHandler(SevenBaseHandler):
    """
    :description: 更新手机号
    """
    @filter_check_params("telephone")
    def get_async(self):
        """
        :description: 更新手机号
        :param telephone：手机号
        :param check_code：验证码
        :return: 
        :last_editors: HuangJingCan
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_param("app_id")
        telephone = self.get_param("telephone")
        check_code = self.get_param("check_code")
        modify_date = self.get_now_datetime()

        check_code_re = self.redis_init().get("user_" + open_id + "_bind_phone_code")
        if check_code_re == None:
            return self.reponse_json_error("CheckCodeError", "验证码已过期")

        check_code_re = str(check_code_re, 'utf-8')

        if check_code != check_code_re:
            return self.reponse_json_error("CheckCodeError", "验证码错误")

        AppInfoModel(context=self).update_table("app_telephone=%s,modify_date=%s", "app_id=%s", [telephone, modify_date, app_id])

        return self.reponse_json_success()


class AppUpdateHandler(TopBaseHandler):
    """
    :description: 前端版本更新
    """
    @filter_check_params()
    def get_async(self):
        """
        :description: 前端版本更新
        :param app_id:app_id
        :return: 
        :last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")
        client_template_id = config.get_value("client_template_id")
        test_client_ver = config.get_value("test_client_ver")
        access_token = self.get_taobao_param().access_token

        base_info = BaseInfoModel(context=self).get_entity()
        client_ver = base_info.client_ver

        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("NoApp", "对不起，找不到该APP")

        old_app_info = deepcopy(app_info)

        #指定账号升级
        if test_client_ver:
            user_nick = self.get_taobao_param().user_nick
            if user_nick:
                if user_nick == config.get_value("test_user_nick"):
                    client_ver = test_client_ver

        return self.app_update(app_id, client_template_id, client_ver, access_token, app_info, old_app_info)


class AppInfoHandler(TopBaseHandler):
    """
    :description: 小程序信息
    """
    @filter_check_params()
    def get_async(self):
        """
        :description: 小程序信息
        :param 
        :return app_info
        :last_editors: HuangJingCan
        """
        store_user_nick = self.get_taobao_param().user_nick.split(':')[0]
        if not store_user_nick:
            return self.reponse_json_error("Error", "对不起，请先授权登录")
        open_id = self.get_taobao_param().open_id
        if not open_id:
            return self.reponse_json_error("Error", "对不起，请先登录")
        open_id = self.get_taobao_param().open_id

        app_info_model = AppInfoModel(context=self)
        app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)

        dead_date = self.get_dead_date(store_user_nick)

        login_log = LoginLogModel(context=self).get_entity("open_id=%s", order_by="id desc", params=open_id)

        if app_info:
            access_token = self.get_token()
            if access_token != "":
                app_info.access_token = access_token
            if dead_date != "expire":
                app_info.expiration_date = dead_date
            app_info_model.update_entity(app_info)

            app_info.surplus_value = 0
            app_info.user_nick = self.get_taobao_param().user_nick
            app_info.dead_date = dead_date
            if app_info.dead_date != "expire":
                now_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(TimeHelper.get_now_format_time('%Y-%m-%d 00:00:00'), '%Y-%m-%d %H:%M:%S'))
                dead_date_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(app_info.dead_date, '%Y-%m-%d %H:%M:%S'))
                app_info.surplus_day = int(int(abs(dead_date_timestamp - now_timestamp)) / 24 / 3600)

            if login_log:
                app_info.last_login_date = login_log.modify_date
            else:
                app_info.last_login_date = ""

            return self.reponse_json_success(app_info)

        app_info = AppInfo()
        app_info.access_token = self.get_taobao_param().access_token
        base_info = BaseInfoModel(context=self).get_dict()
        app_info.template_ver = base_info["client_ver"]
        app_info.surplus_value = 0
        app_info.user_nick = self.get_taobao_param().user_nick
        app_info.dead_date = dead_date

        if app_info.dead_date != "expire":
            now_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(TimeHelper.get_now_format_time('%Y-%m-%d 00:00:00'), '%Y-%m-%d %H:%M:%S'))
            dead_date_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(app_info.dead_date, '%Y-%m-%d %H:%M:%S'))
            app_info.surplus_day = int(int(abs(dead_date_timestamp - now_timestamp)) / 24 / 3600)

        if login_log:
            app_info.last_login_date = login_log.create_date
        else:
            app_info.last_login_date = ""

        return self.reponse_json_success(app_info)


# class AppInfoUpdateHandler(TopBaseHandler):
#     """
#     :description: 更新appinfo相关信息
#     """
#     @filter_check_params()
#     def get_async(self):
#         """
#         :description: 更新appinfo相关信息
#         :param update_field：需要更新的字段
#         :return str
#         :last_editors: HuangJingCan
#         """
#         update_field = self.get_param("update_field")
#         app_info_model = AppInfoModel(context=self)
#         page_size = 100
#         if update_field == "store_icon":
#             where = "store_icon='' and access_token!=''"
#             record_count = app_info_model.get_total(where)
#             page_count = SevenHelper.get_page_count(page_size, record_count)
#             for page_index in range(0, page_count):
#                 p_list, p_total = app_info_model.get_page_list("*", page_index, page_size, where)
#                 for info in p_list:
#                     shop_info = self.get_shop(info.access_token)
#                     if shop_info:
#                         store_icon = shop_info["shop_seller_get_response"]["shop"]["pic_path"]
#                         if store_icon:
#                             store_icon = "http://logo.taobao.com/shop-logo" + store_icon
#                             app_info_model.update_table("store_icon=%s", "id=%s", [store_icon, info.id])

#         return self.reponse_json_success(self.get_now_datetime())



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class RoleMenuModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(RoleMenuModel, self).__init__(RoleMenu, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class RoleMenu:

    def __init__(self):
        super(RoleMenu, self).__init__()
        self.id = 0  # id
        self.menu_name = ""  # 菜单名称
        self.sort_index = 0  # 排序
        self.Is_show = 0  # 是否显示0不显示1显示
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'menu_name', 'sort_index', 'Is_show', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "role_menu_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ActInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(ActInfoModel, self).__init__(ActInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class ActInfo:

    def __init__(self):
        super(ActInfo, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.owner_open_id = ""  # 商家OpenID
        self.act_name = ""  # 活动名称
        self.act_type = 0  # 活动类型
        self.theme_id = 0  # 主题ID
        self.store_url = ""  # 店铺地址
        self.close_word = ""  # 关闭小程序文案
        self.share_desc = ""  # 分享内容
        self.rule_desc = ""  # 规则内容
        self.integral_rule = ""  # 积分规则
        self.start_date = "1900-01-01 00:00:00"  # 开始时间
        self.end_date = "1900-01-01 00:00:00"  # 结束时间
        self.refund_count = 0  # 退款次数
        self.is_black = 0  # 是否开启黑名单
        self.sort_index = 0  # 排序号
        self.menu_configed = ""  # 已配置的菜单
        self.finish_progress = 0  # 完成进度
        self.is_release = 0  # 是否发布（1是0否）
        self.is_throw = 0  # 是否开启投放（1是0否）
        self.is_del = 0  # 是否删除（1是0否）
        self.join_ways = 0  # 活动参与条件（0所有1关注店铺2加入会员）
        self.is_fictitious = 0  # 是否开启虚拟中奖（1是0否）
        self.currency_type = 0  # 抽奖货币类型（0无1次数2积分3价格档位4抽奖码）
        self.task_currency_type = ""  # 任务货币类型（字典数组）
        self.lottery_value = 0  # 单次抽奖消耗次数（积分）
        self.thank_partake_pic = ""  # 谢谢参与图片
        self.thank_partake_title = ""  # 谢谢参与标题
        self.release_date = "1900-01-01 00:00:00"  # 发布时间
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'owner_open_id', 'act_name', 'act_type', 'theme_id', 'store_url', 'close_word', 'share_desc', 'rule_desc', 'integral_rule', 'start_date', 'end_date', 'refund_count', 'is_black', 'sort_index', 'menu_configed', 'finish_progress', 'is_release', 'is_throw', 'is_del', 'join_ways', 'is_fictitious', 'currency_type', 'task_currency_type', 'lottery_value', 'thank_partake_pic', 'thank_partake_title', 'release_date', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "act_info_tb"
    


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-03-11 14:45:09
@LastEditTime: 2021-04-23 14:58:59
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.user.user_info_model import *
from seven_cloudapp.models.db_models.lottery.lottery_value_log_model import *
from seven_cloudapp.models.db_models.exchange.exchange_info_model import *
from seven_cloudapp.models.db_models.user.user_detail_model import *
from seven_cloudapp.models.db_models.prop.prop_log_model import *


class ExchangeListHandler(SevenBaseHandler):
    """
    :description: 兑换列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 兑换列表
        :param act_id:活动id
        :return: 
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))
        condition = "act_id=%s and is_release=1"
        exchange_info_model = ExchangeInfoModel(context=self)
        result = {}
        result["tool_list"] = []
        exchange_info_list = exchange_info_model.get_dict_list(condition, order_by="id asc", params=[act_id])
        if len(exchange_info_list) > 0:
            for item in exchange_info_list:
                data = {}
                if int(item["goods_type"]) == 2:
                    data["goods_detail"] = "可额外获得一次显示机会"
                elif int(item["goods_type"]) == 3:
                    data["goods_detail"] = "可额外获得一次提示机会"
                else:
                    data["goods_detail"] = "可重新获得一次抽盒机会"
                data["exchange_id"] = item["id"]
                data["goods_type"] = item["goods_type"]
                data["goods_name"] = item["goods_name"]
                data["need_value"] = item["need_value"]
                result["tool_list"].append(data)

        return self.reponse_json_success(result)


class ExchangeHandler(SevenBaseHandler):
    """
    :description: 兑换
    """
    @filter_check_params("act_id,exchange_id,login_token")
    def get_async(self):
        """
        :param act_id：活动id
        :param user_id：用户id
        :param exchange_id:兑换id
        :param login_token:用户访问令牌
        :return: 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        exchange_id = int(self.get_param("exchange_id", 0))
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))
        now_day = SevenHelper.get_now_day_int()

        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self)
        exchange_info_model = ExchangeInfoModel(db_transaction=db_transaction, context=self)
        prop_log_model = PropLogModel(db_transaction=db_transaction, context=self)
        user_detail_model = UserDetailModel(db_transaction=db_transaction, context=self)
        lottery_value_log_model = LotteryValueLogModel(db_transaction=db_transaction, context=self)

        #请求太频繁限制
        if self.check_post(f"ExchangeHandler_Get_{str(open_id)}") == False:
            return self.reponse_json_error("HintMessage", "对不起，请求太频繁")

        exchange_info = exchange_info_model.get_entity_by_id(exchange_id)
        if not exchange_info or exchange_info.is_release == 0:
            return self.reponse_json_error("Error", "对不起，当前兑换不存在")
        #获取当前用户
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        if not user_info:
            return self.reponse_json_error("NoUser", "对不起，用户不存在")

        history_value = 0
        user_detail = user_detail_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        if user_detail:
            if exchange_info.goods_type == 2:
                history_value = user_detail.perspective_card_count
            elif exchange_info.goods_type == 3:
                history_value = user_detail.tips_card_count
            elif exchange_info.goods_type == 4:
                history_value = user_detail.redraw_card_count

        if user_info.user_state == 1:
            return self.reponse_json_error("UserState", "账号异常，请联系客服处理")
        if user_info.login_token != login_token:
            return self.reponse_json_error("Error", "对不起，已在另一台设备登录")
        if user_info.surplus_integral < exchange_info.need_value:
            return self.reponse_json_error("Error", "对不起，积分不足")

        now_datetime = self.get_now_datetime()
        update_result = exchange_info_model.update_table("draw_num=draw_num+1", "id=%s", params=[exchange_info.id])
        if update_result:
            try:
                db_transaction.begin_transaction()
                #创建道具记录
                prop_log = PropLog()
                prop_log.app_id = app_id
                prop_log.act_id = act_id
                prop_log.open_id = open_id
                prop_log.user_nick = user_info.user_nick
                prop_log.change_type = 2
                prop_log.operate_type = 0
                prop_log.prop_type = exchange_info.goods_type
                prop_log.operate_value = 1
                prop_log.history_value = history_value
                prop_log.title = f"兑换得到{exchange_info.goods_name}"
                prop_log.create_date_int = SevenHelper.get_now_day_int()
                prop_log.create_date = now_datetime
                prop_log_model.add_entity(prop_log)
                #创建积分记录
                lottery_value_log = LotteryValueLog()
                lottery_value_log.app_id = app_id
                lottery_value_log.act_id = act_id
                lottery_value_log.open_id = open_id
                lottery_value_log.user_nick = user_info.user_nick
                lottery_value_log.log_title = f"兑换{exchange_info.goods_name}"
                lottery_value_log.log_desc = f"兑换ID:{exchange_info.id}"
                lottery_value_log.log_info = {}
                lottery_value_log.currency_type = 2
                lottery_value_log.source_type = 5
                lottery_value_log.change_type = 501
                lottery_value_log.operate_type = 1
                lottery_value_log.current_value = -exchange_info.need_value
                lottery_value_log.history_value = user_info.surplus_integral
                lottery_value_log.create_date = self.get_now_datetime()
                lottery_value_log_model.add_entity(lottery_value_log)

                update_user_detail = ""
                if exchange_info.goods_type == 2:
                    update_user_detail = "perspective_card_count=perspective_card_count+1"
                elif exchange_info.goods_type == 3:
                    update_user_detail = "tips_card_count=tips_card_count+1"
                else:
                    update_user_detail = "redraw_card_count=redraw_card_count+1"
                user_info_model.update_table("surplus_integral=surplus_integral-%s,modify_date=%s", f"id={user_info.id} and surplus_integral={user_info.surplus_integral}", params=[exchange_info.need_value, now_datetime])
                user_detail_model.update_table(update_user_detail, "act_id=%s and open_id=%s", params=[act_id, open_id])
                db_transaction.commit_transaction()
            except Exception as ex:
                db_transaction.rollback_transaction()
                exchange_info_model.update_table("draw_num=draw_num-1", "id=%s", params=[exchange_info.id])
                self.logging_link_info("ExchangeHandler:" + str(ex))
        else:
            return self.reponse_json_error("Error", "当前人数过多,请稍后再试")

        return self.reponse_json_success()



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ThrowGoodsModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(ThrowGoodsModel, self).__init__(ThrowGoods, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class ThrowGoods:

    def __init__(self):
        super(ThrowGoods, self).__init__()
        self.id = 0  # ID
        self.app_id = ""  # app_id
        self.act_id = 0  # 活动ID
        self.goods_id = 0  # 商品ID
        self.prize_id = 0  # 奖品ID
        self.is_throw = 0  # 是否投放(0：不投放  1：投放)
        self.is_sync = 0  # 是否同步（0不同步  1：同步）
        self.error_message = ""  # 同步失败原因
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.throw_date = "1900-01-01 00:00:00"  # 投放时间
        self.sync_date = "1900-01-01 00:00:00"  # 同步时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'goods_id', 'prize_id', 'is_throw', 'is_sync', 'error_message', 'create_date', 'throw_date', 'sync_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "throw_goods_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-11-03 16:25:11
:LastEditTime: 2021-03-17 11:13:56
:LastEditors: HuangJingCan
:description: 
"""

from seven_cloudapp.models.db_models.machine.machine_info_model import *
from seven_cloudapp.models.db_models.throw.throw_goods_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *


class ThrowModel():
    """
    :description: 投放相关
    """
    def __init__(self, context=None):
        self.context = context

    def throw_goods_add(self, object_id, app_id, act_id, goods_id, old_act_id, old_goods_id, now_datetime):
        """
        :description: 投放商品处理
        :param object_id：对象id（机台id或者奖品id）
        :param app_id：app_id
        :param act_id：活动id
        :param goods_id：投放id
        :param old_act_id：旧活动id
        :param old_goods_id：旧投放id
        :param now_datetime：当前时间
        :return
        :last_editors: HuangJingCan
        """
        act_info = ActInfoModel(context=self.context).get_dict_by_id(act_id)
        if act_info and act_info["is_throw"] == 1:
            throw_goods_model = ThrowGoodsModel(context=self.context)
            if object_id > 0:
                # 商品ID与之前不同的话，改变原该投放商品的状态，并添加新商品ID
                if goods_id != old_goods_id:
                    machine_info_model = MachineInfoModel(context=self.context)
                    prize_throw_goods_exist = ActPrizeModel(context=self.context).get_dict("act_id=%s and goods_id=%s", params=[act_id, old_goods_id])
                    machine_throw_goods_exist = machine_info_model.get_dict("act_id=%s and goods_id=%s", params=[act_id, old_goods_id])
                    if not prize_throw_goods_exist and not machine_throw_goods_exist:
                        throw_goods_model.update_table("is_throw=0,throw_date=%s,is_sync=0", "act_id=%s and goods_id=%s", params=[now_datetime, old_act_id, old_goods_id])

                    throw_goods = throw_goods_model.get_entity("act_id=%s and goods_id=%s", params=[act_id, goods_id])
                    if not throw_goods:
                        throw_goods = ThrowGoods()
                        throw_goods.app_id = app_id
                        throw_goods.act_id = act_id
                        throw_goods.goods_id = goods_id
                        throw_goods.is_throw = 0
                        throw_goods.is_sync = 0
                        throw_goods_model.add_entity(throw_goods)
            else:
                throw_goods = throw_goods_model.get_entity("act_id=%s and goods_id=%s", params=[act_id, goods_id])
                if not throw_goods:
                    throw_goods = ThrowGoods()
                    throw_goods.app_id = app_id
                    throw_goods.act_id = act_id
                    throw_goods.goods_id = goods_id
                    throw_goods.is_throw = 0
                    throw_goods.is_sync = 0
                    throw_goods_model.add_entity(throw_goods)

    def throw_goods_update(self, act_id, goods_id, now_datetime):
        """
        :description: 投放商品处理
        :param act_id：活动id
        :param goods_id：投放id
        :param now_datetime：当前时间
        :return
        :last_editors: HuangJingCan
        """
        act_info = ActInfoModel(context=self.context).get_dict_by_id(act_id)
        if act_info and act_info["is_throw"] == 1:
            throw_goods_model = ThrowGoodsModel(context=self.context)
            machine_info_model = MachineInfoModel(context=self.context)
            prize_throw_goods_exist = ActPrizeModel(context=self.context).get_dict("act_id=%s and goods_id=%s", params=[act_id, goods_id])
            machine_throw_goods_exist = machine_info_model.get_dict("act_id=%s and goods_id=%s", params=[act_id, goods_id])
            if not prize_throw_goods_exist and not machine_throw_goods_exist:
                throw_goods_model.update_table("is_throw=0,throw_date=%s,is_sync=0", "act_id=%s and goods_id=%s", params=[now_datetime, act_id, goods_id])

    def init_throw_goods_list(self, act_id, app_id, act_name, online_url, goods_id_list, now_datetime):
        """
        :description: 初始化活动投放
        :param act_id:活动id
        :param app_id:app_id
        :param act_name:活动名称
        :param online_url:online_url
        :param goods_id_list:商品id列表
        :return dict
        :last_editors: HuangJingCan
        """
        throw_goods_model = ThrowGoodsModel(context=self.context)

        goods_ids = ",".join([str(i) for i in goods_id_list])

        throw_goods_exist_list = throw_goods_model.get_dict_list("act_id<>%s and goods_id in (" + goods_ids + ")", field="goods_id", params=act_id)
        throw_goods_id_exist_list = [i for i in throw_goods_exist_list]

        throw_goods_list = []

        for goods_id in goods_id_list:
            throw_goods = ThrowGoods()
            throw_goods.app_id = app_id
            throw_goods.act_id = act_id
            throw_goods.goods_id = goods_id
            if goods_id in throw_goods_id_exist_list:
                throw_goods.is_throw = 0
                throw_goods.is_sync = 0
            else:
                throw_goods.is_throw = 1
                throw_goods.is_sync = 1
            throw_goods.create_date = now_datetime
            throw_goods.throw_date = now_datetime
            throw_goods.sync_date = now_datetime
            throw_goods_list.append(throw_goods)

        throw_goods_model.add_list(throw_goods_list)

        result_data = {"url": online_url, "act_name": act_name, "goods_list": goods_id_list}

        return result_data



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PrizeOrderModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(PrizeOrderModel, self).__init__(PrizeOrder, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PrizeOrder:

    def __init__(self):
        super(PrizeOrder, self).__init__()
        self.id = 0  # id
        self.order_no = ""  # 订单号
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.owner_open_id = ""  # 商家OpenID
        self.user_nick = ""  # 用户昵称
        self.real_name = ""  # 真实姓名
        self.telephone = ""  # 手机号码
        self.province = ""  # 所在省
        self.city = ""  # 所在市
        self.county = ""  # 所在区
        self.street = ""  # 所在街道
        self.adress = ""  # 收货地址
        self.deliver_date = "1900-01-01 00:00:00"  # 发货时间
        self.express_no = ""  # 快递单号
        self.express_company = ""  # 快递公司
        self.order_status = 0  # 状态（0未发货1已发货2不予发货）
        self.remarks = ""  # 备注
        self.sync_status = 0  # 订单同步状态（0-未同步，1-同步成功，2-同步失败）
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'order_no', 'app_id', 'act_id', 'open_id', 'owner_open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'adress', 'deliver_date', 'express_no', 'express_company', 'order_status', 'remarks', 'sync_status', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "prize_order_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: CaiYouBin
:Date: 2020-06-01 14:07:23
:LastEditTime: 2021-04-16 10:39:58
:LastEditors: HuangJingCan
:description: 商品相关
"""
from seven_cloudapp.handlers.top_base import *

from seven_cloudapp.models.db_models.machine.machine_info_model import *
from seven_cloudapp.models.db_models.price.price_gear_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.recommend.recommend_goods_model import *


class GoodsListHandler(TopBaseHandler):
    """
    :description: 导入商品列表（获取当前会话用户出售中的商品列表）
    """
    def get_async(self):
        """
        :description: 导入商品列表（获取当前会话用户出售中的商品列表）
        :param goods_name：商品名称
        :param order_tag：order_tag
        :param order_by：排序类型
        :param page_index：页索引
        :param page_size：页大小
        :return: 列表
        :last_editors: HuangJingCan
        """
        access_token = self.get_taobao_param().access_token
        goods_name = self.get_param("goods_name")
        order_tag = self.get_param("order_tag", "list_time")
        order_by = self.get_param("order_by", "desc")
        page_index = int(self.get_param("page_index", 0))
        page_size = self.get_param("page_size", 10)

        return self.get_goods_list(page_index, page_size, goods_name, order_tag, order_by, access_token)


class GoodsListByGoodsIDHandler(TopBaseHandler):
    """
    :description: 根据商品id获取商品列表
    """
    @filter_check_params("goods_ids")
    def get_async(self):
        """
        :description: 根据商品id获取商品列表
        :param goods_id：商品id
        :param is_check_exist：是否存在
        :return: list
        :last_editors: HuangJingCan
        """
        access_token = self.get_taobao_param().access_token
        goods_ids = self.get_param("goods_ids")

        resp = self.get_goods_list_for_goodsids(goods_ids, access_token)

        if "error_message" in resp.keys():
            return self.reponse_json_error("Error", resp["error_message"])

        return self.reponse_json_success(resp)


class GoodsInfoHandler(TopBaseHandler):
    """
    :description: 获取商品信息
    """
    @filter_check_params("goods_id")
    def get_async(self):
        """
        :description: 获取商品信息
        :param goods_id：商品id
        :param machine_id：机台id
        :param is_check_exist：是否存在
        :return: 商品信息
        :last_editors: HuangJingCan
        """
        access_token = self.get_taobao_param().access_token
        num_iid = self.get_param("goods_id")
        machine_id = int(self.get_param("machine_id", 0))
        is_check_machine_exist = int(self.get_param("is_check_exist", 0))

        if is_check_machine_exist > 0:
            exist_machineed = MachineInfoModel(context=self).get_dict("goods_id=%s and id<>%s", params=[num_iid, machine_id])
            if exist_machineed:
                return self.reponse_json_error("ExistGoodsID", "对不起，当前商品ID已应用到其他盒子中")

        return self.get_goods_info(num_iid, access_token)


class GoodsCheckHandler(TopBaseHandler):
    """
    :description: 校验商品
    """
    @filter_check_params("goods_id,act_id")
    def get_async(self):
        """
        :description: 校验商品
        :param goods_id：商品id
        :param act_id：活动id
        :return: 商品信息
        :last_editors: HuangJingCan
        """
        access_token = self.get_taobao_param().access_token
        num_iid = self.get_param("goods_id")
        act_id = int(self.get_param("act_id", 0))

        condition = "act_id!=%s and goods_id=%s"
        price_gear_dict = PriceGearModel(context=self).get_dict(condition, params=[act_id, num_iid])
        if price_gear_dict:
            act_dict = ActInfoModel(context=self).get_dict_by_id(price_gear_dict['act_id'])
            actName = act_dict['act_name'] if act_dict else ""
            return self.reponse_json_error("ParamError", f"此商品ID已关联活动{actName},无法使用！")
        else:
            return self.get_goods_info(num_iid, access_token)


class GetCouponDetails(TopBaseHandler):
    """
    :description: 获取优惠券详情信息
    """
    def get_async(self):
        """
        :description: 获取优惠券详情信息
        :param right_ename:奖池ID
        :return: dict
        :last_editors: LaiKaiXiang
        """
        right_ename = self.get_param("right_ename")

        return self.get_coupon_details(right_ename)


class RecommendGoodsHandler(SevenBaseHandler):
    """ 
    保存爆品推荐
    """
    @filter_check_params("act_id,app_id")
    def post_async(self):
        """
        :description: 保存爆品推荐
        :param app_id：app_id
        :param act_id：act_id
        :param goods_ids：推荐商品id(逗号,分隔)
        :param goods_list：推荐商品列表
        :param is_open：是否开启
        :return reponse_json_success
        :last_editors: LaiKaiXiang
        """
        act_id = int(self.get_param("act_id", 0))
        app_id = self.get_param("app_id")
        is_release = int(self.get_param("is_open", 0))
        goods_ids = self.get_param("goods_ids")
        goods_list = self.get_param("goods_list")
        goods_list = goods_list if goods_list != "" else []

        if act_id <= 0:
            return self.reponse_json_error_params()

        recommend_goods_model = RecommendGoodsModel(context=self)
        recommend_goods = recommend_goods_model.get_entity("act_id=%s", params=act_id)
        if recommend_goods:
            recommend_goods.is_release = is_release
            recommend_goods.goods_ids = goods_ids
            recommend_goods.goods_list = goods_list
            recommend_goods.modify_date = self.get_now_datetime()
            recommend_goods_model.update_entity(recommend_goods)
        else:
            recommend_goods = RecommendGoods()
            recommend_goods.act_id = act_id
            recommend_goods.app_id = app_id
            recommend_goods.is_release = is_release
            recommend_goods.goods_ids = goods_ids
            recommend_goods.goods_list = goods_list
            recommend_goods.create_date = self.get_now_datetime()
            recommend_goods_model.add_entity(recommend_goods)

        return self.reponse_json_success()


class RecommendGoodsInfoHandler(SevenBaseHandler):
    """
    获取爆品推荐列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取爆品推荐列表
        :param act_id：act_id
        :return list
        :last_editors: LaiKaiXiang
        """
        act_id = int(self.get_param("act_id", 0))

        if act_id <= 0:
            return self.reponse_json_error_params()

        recommend_goods = RecommendGoodsModel(context=self).get_entity("act_id=%s", params=act_id)

        if recommend_goods:
            recommend_goods.goods_list = self.json_loads(recommend_goods.goods_list) if recommend_goods.goods_list else []

        return self.reponse_json_success(recommend_goods)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-16 14:38:22
:LastEditTime: 2021-04-14 16:06:52
:LastEditors: HuangJingCan
:description: 
"""
__all__ = ["act_s", "app_s", "base_s", "exchange_s", "goods_s", "machine_s", "order_s", "power_s", "price_s", "prize_s", "report_s", "series_s", "sms_s", "task_s", "theme_s", "throw_s", "user_s"]




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class BehaviorOrmModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(BehaviorOrmModel, self).__init__(BehaviorOrm, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class BehaviorOrm:

    def __init__(self):
        super(BehaviorOrm, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.act_id = 0  # 活动ID
        self.act_type = 0  # 活动类型id
        self.orm_type = 0  # 类型（1活动2基础）
        self.task_type = 0  # 任务类型
        self.group_name = ""  # 分组名称
        self.group_sub_name = ""  # 分组子名称
        self.key_name = ""  # key名称
        self.key_value = ""  # key值
        self.value_type = 0  # 输出类型：1-int，2-decimal
        self.is_repeat = 0  # 是否去重(1是0否)
        self.repeat_type = 0  # 去重方式(1当日去重2全部去重)
        self.is_common = 0  # 是否公用（1公用0私有）
        self.owner_open_id = ""  # 应用拥有者标识
        self.sort_index = 0  # 排序号
        self.is_release = 0  # 是否发布
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'act_type', 'orm_type', 'task_type', 'group_name', 'group_sub_name', 'key_name', 'key_value', 'value_type', 'is_repeat', 'repeat_type', 'is_common', 'owner_open_id', 'sort_index', 'is_release', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "behavior_orm_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class CoinOrderModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(CoinOrderModel, self).__init__(CoinOrder, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class CoinOrder:

    def __init__(self):
        super(CoinOrder, self).__init__()
        self.id = 0  # id
        self.open_id = ""  # open_id
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.machine_id = 0  # 机台id
        self.reward_type = 0  # 奖励类型
        self.goods_name = ""  # 商品名称
        self.goods_price = 0  # 商品价格
        self.sku = ""  # 商品sku
        self.price_gears_id = 0  # 价格档位ID
        self.nick_name = ""  # 淘宝昵称
        self.main_pay_order_no = ""  # 淘宝主订单编号
        self.pay_order_no = ""  # 淘宝子订单编号
        self.pay_order_id = 0  # 交易订单ID
        self.surplus_count = 0  # 剩余配对数
        self.buy_count = 0  # 购买数量
        self.prize_ids = ""  # 奖品ID列表（逗号隔开）
        self.remark = ""  # 备注
        self.pay_date = "1900-01-01 00:00:00"  # 支付时间
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'open_id', 'app_id', 'act_id', 'machine_id', 'reward_type', 'goods_name', 'goods_price', 'sku', 'price_gears_id', 'nick_name', 'main_pay_order_no', 'pay_order_no', 'pay_order_id', 'surplus_count', 'buy_count', 'prize_ids', 'remark', 'pay_date', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "coin_order_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class OperationLogModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(OperationLogModel, self).__init__(OperationLog, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class OperationLog:

    def __init__(self):
        super(OperationLog, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.user_nick = ""  # 用户昵称
        self.operation_type = 0  # 类型：1-add，2-update，3-delete
        self.title = ""  # 标题
        self.detail = ""  # 当前信息
        self.update_detail = ""  # 更新之后的信息
        self.request_params = ""  # 传入的参数
        self.model_name = ""  # 模块或表名称
        self.protocol = ""  # protocol
        self.method = ""  # method
        self.handler_name = ""  # handler_name
        self.request_host = ""  # request_host
        self.request_uri = ""  # request_uri
        self.remote_ip = ""  # remote_ip
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'open_id', 'user_nick', 'operation_type', 'title', 'detail', 'update_detail', 'request_params', 'model_name', 'protocol', 'method', 'handler_name', 'request_host', 'request_uri', 'remote_ip', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "operation_log_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2020-06-22 10:30:00
:LastEditTime: 2021-06-07 08:35:01
:LastEditors: HuangJingCan
:description: 价格档位
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.enum import OperationType
from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.db_models.price.price_gear_model import *
from seven_cloudapp.models.db_models.throw.throw_goods_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
# from seven_cloudapp.models.db_models.machine.machine_info_model import *


class PriceHandler(SevenBaseHandler):
    """
    :description: 保存价格档位
    """
    @filter_check_params("app_id,act_id,price")
    def get_async(self):
        """
        :description: 保存价格档位
        :param app_id：app_id
        :param price_gear_id：价格挡位id
        :param act_id：活动id
        :param price：价格
        :param goods_id：商品id
        :param sku_id：sku_id
        :return: reponse_json_success
        :last_editors: HuangJianYi
        """
        app_id = self.get_param("app_id")
        open_id = self.get_taobao_param().open_id
        price_gear_id = int(self.get_param("price_gear_id", 0))
        act_id = int(self.get_param("act_id", 0))
        relation_type = int(self.get_param("relation_type", 1))
        price = self.get_param("price")
        price_gear_name = self.get_param("price_gear_name")
        price_gear_pic = self.get_param("price_gear_pic")
        goods_id = self.get_param("goods_id")
        sku_id = self.get_param("sku_id")

        if act_id <= 0:
            return self.reponse_json_error_params()

        price_gear = None
        old_price_gear = None
        price_gear_model = PriceGearModel(context=self)
        if price_gear_id > 0:
            price_gear = price_gear_model.get_entity_by_id(price_gear_id)

        is_add = False
        if not price_gear:
            is_add = True
            price_gear = PriceGear()
        else:
            old_price_gear = deepcopy(price_gear)

        try:
            price = decimal.Decimal(price)
        except Exception as ex:
            # self.logging_link_error(str(ex) + "【保存价格档位】")
            return self.reponse_json_error("ParamError", "参数price类型错误")

        if goods_id != "":
            condition = "act_id!=%s and goods_id=%s"
            price_gear_goodsid = price_gear_model.get_entity(condition, params=[act_id, goods_id])
            if price_gear_goodsid:
                act_info = ActInfoModel(context=self).get_dict_by_id(price_gear_goodsid.act_id)
                actName = act_info["act_name"] if act_info else ""
                return self.reponse_json_error("Error", f"此商品ID已关联活动{actName},无法使用")

        price_gear.act_id = act_id
        price_gear.app_id = app_id
        price_gear.relation_type = relation_type
        price_gear.price = price
        price_gear.price_gear_name = price_gear_name
        price_gear.price_gear_pic = price_gear_pic
        price_gear.goods_id = goods_id
        price_gear.sku_id = sku_id
        price_gear.modify_date = self.get_now_datetime()

        if is_add:
            if sku_id != "":
                price_gear_goodsid_skuid = price_gear_model.get_entity("sku_id=%s", params=[sku_id])
                if price_gear_goodsid_skuid:
                    return self.reponse_json_error("Error", f"当前SKUID已绑定价格档位,请更换")
            price_gear.effective_date = self.get_now_datetime()
            price_gear.id = price_gear_model.add_entity(price_gear)
            # 记录日志
            self.create_operation_log(OperationType.add.value, price_gear.__str__(), "PriceHandler", None, self.json_dumps(price_gear))
        else:
            if sku_id != "":
                price_gear_goodsid_skuid = price_gear_model.get_entity("id!=%s and sku_id=%s", params=[price_gear.id, sku_id])
                if price_gear_goodsid_skuid:
                    return self.reponse_json_error("Error", f"当前SKUID已绑定价格档位,请更换")
            price_gear_model.update_entity(price_gear)
            # 记录日志
            self.create_operation_log(OperationType.update.value, price_gear.__str__(), "PriceHandler", self.json_dumps(old_price_gear), self.json_dumps(price_gear))

        self.throw_goods_add(price_gear_id, price_gear, old_price_gear)

        return self.reponse_json_success(price_gear.id)

    def throw_goods_add(self, price_gear_id, price_gear, old_price_gear):
        """
        :description: 投放商品处理
        :param price_gear_id：价格挡位id
        :param price_gear：价格挡位对象
        :param old_price_gear：旧价格挡位对象
        :return: 
        :last_editors: HuangJianYi
        """
        act_info = ActInfoModel(context=self).get_dict_by_id(price_gear.act_id)
        if act_info and act_info["is_throw"] == 1:
            throw_goods_model = ThrowGoodsModel(context=self)
            if price_gear_id > 0:
                # 商品ID与之前不同的话，改变原该投放商品的状态，并添加新商品ID
                if price_gear.goods_id != old_price_gear.goods_id:
                    prize_gear_model = PriceGearModel(context=self)
                    gear_throw_goods_exist = prize_gear_model.get_entity("act_id=%s and goods_id=%s", params=[price_gear.act_id, old_price_gear["goods_id"]])
                    if not gear_throw_goods_exist:
                        throw_goods_model.update_table("is_throw=0,throw_date=%s,is_sync=0", "act_id=%s and goods_id=%s", params=[self.get_now_datetime(), old_price_gear["act_id"], old_price_gear["goods_id"]])

                    throw_goods = throw_goods_model.get_entity("act_id=%s and goods_id=%s", params=[price_gear.act_id, price_gear.goods_id])
                    if not throw_goods:
                        throw_goods = ThrowGoods()
                        throw_goods.app_id = price_gear.app_id
                        throw_goods.act_id = price_gear.act_id
                        throw_goods.goods_id = price_gear.goods_id
                        throw_goods.is_throw = 0
                        throw_goods.is_sync = 0
                        throw_goods_model.add_entity(throw_goods)
            else:
                throw_goods = throw_goods_model.get_entity("act_id=%s and goods_id=%s", params=[price_gear.act_id, price_gear.goods_id])
                if not throw_goods:
                    throw_goods = ThrowGoods()
                    throw_goods.app_id = price_gear.app_id
                    throw_goods.act_id = price_gear.act_id
                    throw_goods.goods_id = price_gear.goods_id
                    throw_goods.is_throw = 0
                    throw_goods.is_sync = 0
                    throw_goods_model.add_entity(throw_goods)


class PriceListHandler(SevenBaseHandler):
    """
    :description: 获取价格档位列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取价格档位列表
        :param act_id：活动id
        :param page_index：页索引
        :param page_size：页大小
        :return: 列表
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))

        if act_id <= 0:
            return self.reponse_json_error_params()

        page_list, total = PriceGearModel(context=self).get_dict_page_list("*", page_index, page_size, "act_id=%s and is_del=0", "", "id desc", act_id)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


class PriceListRecoverHandler(SevenBaseHandler):
    """
    :description: 价格档位回收站
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 价格档位回收站
        :param act_id：活动id
        :param page_index：页索引
        :param page_size：页大小
        :return: 列表
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))

        if act_id <= 0:
            return self.reponse_json_error_params()

        page_list, total = PriceGearModel(context=self).get_dict_page_list("*", page_index, page_size, "act_id=%s and is_del=1", "", "id desc", act_id)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


class PriceStatusHandler(SevenBaseHandler):
    """
    :description: 价格档位删除和恢复
    """
    @filter_check_params("price_gear_id")
    def get_async(self):
        """
        :description: 删除价格档位
        :param app_id：app_id
        :param price_gear_id：价格档位id
        :param status：状态
        :return: 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_param("app_id")
        price_gear_id = int(self.get_param("price_gear_id", 0))
        status = int(self.get_param("status", 0))
        if status > 0:
            status = 1
        if price_gear_id <= 0:
            return self.reponse_json_error_params()
        price_gear_model = PriceGearModel(context=self)
        # machine_info_model = MachineInfoModel(context=self)
        # machine_info = machine_info_model.get_entity("app_id=%s and price_gears_id=%s", params=[app_id,price_gear_id])
        # if machine_info:
        #     return self.reponse_json_error("Error", "当前档位已关联中盒,请取消关联再删除")
        price_gear = price_gear_model.get_entity_by_id(price_gear_id)
        price_gear_model.update_table("is_del=%s,goods_id='',sku_id=''", "id=%s", [status, price_gear_id])
        if status == 1:
            self.throw_goods_update(price_gear)
            # 记录日志
            self.create_operation_log(OperationType.delete.value, "price_gear_tb", "PriceStatusHandler", None, price_gear_id)

        return self.reponse_json_success()

    def throw_goods_update(self, price_gear):
        """
        :description: 投放商品处理
        :param price_gear：价格挡位
        :return: 
        :last_editors: HuangJianYi
        """
        act_info = ActInfoModel(context=self).get_dict_by_id(price_gear.act_id)
        if act_info and act_info["is_throw"] == 1:
            ThrowGoodsModel(context=self).update_table("is_throw=0,throw_date=%s,is_sync=0", "act_id=%s and goods_id=%s", params=[self.get_now_datetime(), price_gear.act_id, price_gear.goods_id])



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ThemeInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(ThemeInfoModel, self).__init__(ThemeInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class ThemeInfo:

    def __init__(self):
        super(ThemeInfo, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用唯一标识
        self.is_private = 0  # 是否发布（1私有0公用）
        self.theme_name = ""  # 主题名称
        self.client_json = ""  # 客户端内容json
        self.server_json = ""  # 服务端内容json
        self.out_id = ""  # 外部id
        self.sort_index = 0  # 排序号
        self.is_release = 0  # 是否发布（1发布0未发布）
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'is_private', 'theme_name', 'client_json', 'server_json', 'out_id', 'sort_index', 'is_release', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "theme_info_tb"
    